pub struct PbmGetRange<'a> {
pub return_low: bool,
pub ranges: Option<&'a mut PBRANGE>,
}Available on crate features
comctl and user only.Expand description
PBM_GETRANGE
message parameters.
Return type: i32.
Fields
return_low: boolranges: Option<&'a mut PBRANGE>Trait Implementations
Sourceimpl<'a> MsgSend for PbmGetRange<'a>
impl<'a> MsgSend for PbmGetRange<'a>
Sourcetype RetType = i32
type RetType = i32
Available on crate feature
user only.The specific type of the value returned by the message.
Sourceunsafe fn isize_to_ret(&self, v: isize) -> Self::RetType
unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType
Available on crate feature
user only.Unmarshaling method which converts the generic
isize return value to
the specific type returned by the message. Read moreSourcefn as_generic_wm(&mut self) -> Wm
fn as_generic_wm(&mut self) -> Wm
Available on crate feature
user only.Marshaling method which converts the specific message parameters struct
into the generic
Wm message struct.Auto Trait Implementations
impl<'a> !UnwindSafe for PbmGetRange<'a>
impl<'a> Freeze for PbmGetRange<'a>
impl<'a> RefUnwindSafe for PbmGetRange<'a>
impl<'a> Send for PbmGetRange<'a>
impl<'a> Sync for PbmGetRange<'a>
impl<'a> Unpin for PbmGetRange<'a>
impl<'a> UnsafeUnpin for PbmGetRange<'a>