pub struct PbmSetPos {
pub position: u32,
}Available on crate features
comctl and user only.Expand description
PBM_SETPOS
message parameters.
Return type: u32.
Fields
position: u32Trait Implementations
Sourceimpl MsgSend for PbmSetPos
impl MsgSend for PbmSetPos
Sourcetype RetType = u32
type RetType = u32
Available on crate feature
user only.The specific type of the value returned by the message.
Sourceunsafe fn isize_to_ret(&self, v: isize) -> Self::RetType
unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType
Available on crate feature
user only.Unmarshaling method which converts the generic
isize return value to
the specific type returned by the message. Read moreSourcefn as_generic_wm(&mut self) -> Wm
fn as_generic_wm(&mut self) -> Wm
Available on crate feature
user only.Marshaling method which converts the specific message parameters struct
into the generic
Wm message struct.Auto Trait Implementations
impl Freeze for PbmSetPos
impl RefUnwindSafe for PbmSetPos
impl Send for PbmSetPos
impl Sync for PbmSetPos
impl Unpin for PbmSetPos
impl UnsafeUnpin for PbmSetPos
impl UnwindSafe for PbmSetPos